==> mdx-m3-viewer-5.7.7.tgz: package/src/viewer/handlers/mdx/eventobjectspn.ts <==
import Scene from '../../scene';
import EmittedObject from '../../emittedobject';
import MdxModel from './model';
import EventObjectEmitterObject from './eventobjectemitterobject';
import MdxModelInstance from './modelinstance';
import EventObjectSpnEmitter from './eventobjectspnemitter';

/**
 * An MDX spawned model object.
 */
export default class EventObjectSpn extends EmittedObject {
  internalInstance: MdxModelInstance;

  constructor(emitter: EventObjectSpnEmitter) {
    super(emitter);

    let emitterObject = <EventObjectEmitterObject>emitter.emitterObject;
    let internalModel = <MdxModel>emitterObject.internalModel;

    this.internalInstance = <MdxModelInstance>internalModel.addInstance();
  }

  bind() {
    let emitter = <EventObjectSpnEmitter>this.emitter;
    let instance = <MdxModelInstance>emitter.instance;
    let scene = <Scene>instance.scene;
    let node = instance.nodes[emitter.emitterObject.index];
    let internalInstance = <MdxModelInstance>this.internalInstance;

    internalInstance.setScene(scene);
    internalInstance.setSequence(0);
    internalInstance.setTransformation(node.worldLocation, node.worldRotation, node.worldScale);
    internalInstance.show();

    this.health = 1;
  }

  update(dt: number) {
    let instance = this.internalInstance;
    let model = <MdxModel>instance.model;

    // Once the sequence finishes, this event object dies
    if (instance.frame >= model.sequences[0].interval[1]) {
      this.health = 0;

      instance.hide();
    }
  }
}

==> mdx-m3-viewer-5.9.7.tgz: package/src/viewer/handlers/mdx/eventobjectspn.ts <==
import Scene from '../../scene';
import EmittedObject from '../../emittedobject';
import MdxModel from './model';
import EventObjectEmitterObject from './eventobjectemitterobject';
import MdxModelInstance from './modelinstance';
import EventObjectSpnEmitter from './eventobjectspnemitter';

/**
 * An MDX spawned model object.
 */
export default class EventObjectSpn extends EmittedObject {
  internalInstance: MdxModelInstance;

  constructor(emitter: EventObjectSpnEmitter) {
    super(emitter);

    const emitterObject = <EventObjectEmitterObject>emitter.emitterObject;
    const internalModel = <MdxModel>emitterObject.internalModel;

    this.internalInstance = <MdxModelInstance>internalModel.addInstance();
  }

  bind() {
    const emitter = <EventObjectSpnEmitter>this.emitter;
    const instance = <MdxModelInstance>emitter.instance;
    const scene = <Scene>instance.scene;
    const node = instance.nodes[emitter.emitterObject.index];
    const internalInstance = <MdxModelInstance>this.internalInstance;

    internalInstance.setScene(scene);
    internalInstance.setSequence(0);
    internalInstance.setTransformation(node.worldLocation, node.worldRotation, node.worldScale);
    internalInstance.show();

    this.health = 1;
  }

  update(dt: number) {
    const instance = this.internalInstance;
    const model = <MdxModel>instance.model;

    // Once the sequence finishes, this event object dies
    if (instance.frame >= model.sequences[0].interval[1]) {
      this.health = 0;

      instance.hide();
    }
  }
}
